@@ -1,6 +1,6 @@
 import traceback
 from loguru import logger
-from nonebot import on_command, on_message, get_driver
+from nonebot import get_bot, on_command, on_message, get_driver
 from nonebot.params import CommandArg
 from nonebot.adapters.onebot.v11 import Message, MessageSegment,MessageEvent,Bot
 from nonebot.log import logger
@@ -9,13 +9,15 @@ from .wws_info import get_AccountInfo
 from .wws_recent import get_RecentInfo
 from .wws_bind import set_BindInfo,get_BindInfo,change_BindInfo
 from .wws_ship import get_ShipInfo,SecletProcess
+from .wws_shiprank import get_ShipRank
 from .data_source import command_list
 from .utils import find_and_replace_keywords
 from nonebot_plugin_apscheduler import scheduler
 import httpx
 import json
+import nonebot
 
-__version__ = '0.1.4'
+__version__ = '0.1.6'
 
 WWS_help ="""
     帮助列表
@@ -25,7 +27,9 @@ WWS_help ="""
     wws [服务器+游戏昵称][@群友][me]：查询账号总体战绩
     wws [服务器+游戏昵称][@群友][me] recent [日期]：查询账号近期战绩，默认1天
     wws [服务器+游戏昵称][@群友][me] ship 船名：查询单船总体战绩
+    wws rank/ship.rank [服务器][战舰名]：查询单船排行榜
     wws [搜/查船名] [国家][等级][类型]：查找符合条件的舰船中英文名称
+    wws 检查更新
     [待开发] wws ship recent
     [待开发] wws rank
     以上指令参数顺序均无强制要求，即你完全可以发送wws eu 7 recent Test以查询欧服Test七天内的战绩
@@ -60,7 +64,7 @@ async def selet_command(ev:MessageEvent, matchmsg: Message = CommandArg()):
             select_command,search_list = await find_and_replace_keywords(search_list,command_list)         #第二次匹配
             if not select_command:
                 try:
-                    msg = await get_ShipInfo(qqid,search_list,bot,ev)
+                    msg = await get_ShipInfo(qqid,search_list,bot)
                 except Exception:
                     logger.warning(traceback.format_exc())
                     await bot.finish('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
@@ -81,6 +85,12 @@ async def selet_command(ev:MessageEvent, matchmsg: Message = CommandArg()):
                 msg = '待开发：查单船近期战绩'
             else:
                 msg = '：看不懂指令QAQ'
+        elif select_command == 'ship_rank':
+            try:
+                msg = await get_ShipRank(qqid,search_list,bot)
+            except Exception:
+                logger.warning(traceback.format_exc())
+                await bot.finish('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')    
         elif select_command == 'bind':
             try:
                 msg = await set_BindInfo(qqid,search_list)
@@ -107,14 +117,17 @@ async def selet_command(ev:MessageEvent, matchmsg: Message = CommandArg()):
                 await bot.finish('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
         else:
             msg = '看不懂指令QAQ'
-        if isinstance(msg,str):
-            await bot.finish(msg)
+        if msg:
+            if isinstance(msg,str):
+                await bot.finish(msg)
+            else:
+                await bot.finish(MessageSegment.image(msg))
         else:
-            await bot.finish(MessageSegment.image(msg))
+            await bot.finish('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
             
 @bot_help.handle()      
 async def send_bot_help():
-    await bot.finish(WWS_help)
+    await bot_help.finish(WWS_help)
     
 @bot_listen.handle()
 async def change_select_state(ev:MessageEvent):
@@ -125,8 +138,9 @@ async def change_select_state(ev:MessageEvent):
         SecletProcess[qqid] = SecletProcess[qqid]._replace(SlectIndex = int(msg))
 
 @bot_checkversion.handle()
-async def check_version(bot:Bot):
+async def check_version():
     try:
+        bot = get_bot()
         url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/version.json'
         async with httpx.AsyncClient() as client:
             resp = await client.get(url, timeout=10)
@@ -143,6 +157,10 @@ async def check_version(bot:Bot):
         if match:
             for each in superid:
                 await bot.send_private_msg(user_id=int(each),message=msg)
+            try:
+                await bot_checkversion.send(msg)
+            except Exception:
+                return
         return
     except Exception:
         logger.warning(traceback.format_exc())
@@ -150,8 +168,7 @@ async def check_version(bot:Bot):
         
 scheduler.add_job(
     check_version,
-    "interval",
-    hours=12,
-    id="check_version",
-    args=[Bot]
+    "cron",
+    hour = 12,
+    id="check_version"
 )
